==> kom%2B%2B-0.5.tar.gz: kom++-0.5/www/Makefile.py <==
# Makefile template for WWW-kom
# $Id: Makefile.py,v 1.3 1996/05/08 07:30:25 ceder Exp $
# Copyright (C) 1996  Per Cederqvist and Inge Wallin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

# Process this file with python to generate Makefile.in.

from pmg import *

class pydir_mixin:
    def destination(self):
	return "$(pydir)"

class python_files(pydir_mixin, collection_target):
    def __init__(self):
	self.name = "python"
	collection_target.__init__(self)

class generated_python_file(no_add_dep_mixin, pydir_mixin, collection_target):
    def __init__(self, name):
	self.name = name
	collection_target.__init__(self)
	collection_target.add_dep(self, generated_item(name))

    def emit_variables(self):
	pass

    def add_clean_info(self, makefile):
	makefile.mostlyclean(self.name)

m = komxxmakefile()
m.add_subdir("html",
	     [("install",[]),
	      ("installdirs",[])],
	     ["WWW_KOM"])

m.add_target(sbin_shellscript("lm"), "all", ["WWW_KOM"])
m.add_target(libexec_shellscript("sc"), "all", ["WWW_KOM"])

t = python_files()
python = ["komhtml.py", "language.py", "lm.py",
	  "myhttpbase.py", "myserver.py", "sc.py",
	  "komtext.py", "toolbar.py"]

for p in python:
    t.add_dep(item(p))

m.add_target(t, None, ["WWW_KOM"])

m.add_target(generated_python_file("komconfig.py"), "all", ["WWW_KOM"])

m.emit()

print """
# Where to install Python files
pydir = $(datadir)/wwwkom/$(VERSION)/py
htmldir = $(datadir)/wwwkom/$(VERSION)/html

sc: $(srcdir)/sc.sh Makefile
	$(RM) sc.tmp
	sed \\
		-e "s/SERVER/$(DEFAULT_SERVER)/" \\
		-e "s/PORT/$(DEFAULT_PORT)/" \\
		-e "s+PYDIR+$(pydir)+" \\
		-e "s+HTMLDIR+$(htmldir)+" \\
		-e "s+LIBEXECDIR+$(libexecdir)+" \\
		< $(srcdir)/sc.sh > sc.tmp
	chmod +x sc.tmp
	mv -f sc.tmp sc

lm: $(srcdir)/lm.sh Makefile
	$(RM) lm.tmp
	sed \\
		-e "s/SERVER/$(DEFAULT_SERVER)/" \\
		-e "s/PORT/$(DEFAULT_PORT)/" \\
		-e "s+PYDIR+$(pydir)+" \\
		-e "s+HTMLDIR+$(htmldir)+" \\
		-e "s+LIBEXECDIR+$(libexecdir)+" \\
		< $(srcdir)/lm.sh > lm.tmp
	chmod +x lm.tmp
	mv -f lm.tmp lm

komconfig.py: Makefile
	(echo 'wwwhost="'`hostname`.`domainname`'"'; echo 'wwwport="'8494'"') > komconfig.py
"""

==> kom%2B%2B-0.6.tar.gz: kom++-0.6/www/Makefile.py <==
# Makefile template for WWW-kom
# $Id: Makefile.py,v 1.5 1996/07/19 12:16:16 ceder Exp $
# Copyright (C) 1996  Per Cederqvist and Inge Wallin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

# Process this file with python to generate Makefile.in.

from pmg import *

class pydir_mixin:
    def destination(self):
	return "$(pydir)"

class python_files(pydir_mixin, collection_target):
    def __init__(self):
	self.name = "python"
	collection_target.__init__(self)

class generated_python_file(no_add_dep_mixin, pydir_mixin, collection_target):
    def __init__(self, name):
	self.name = name
	collection_target.__init__(self)
	collection_target.add_dep(self, generated_item(name))

    def emit_variables(self):
	pass

    def add_clean_info(self, makefile):
	makefile.mostlyclean(self.name)

m = komxxmakefile()
m.add_subdir("html",
	     [("install",[]),
	      ("installdirs",[])],
	     ["WWW_KOM"])

m.add_target(sbin_shellscript("lm"), "all", ["WWW_KOM"])
m.add_target(libexec_shellscript("sc"), "all", ["WWW_KOM"])

t = python_files()
python = ["komhtml.py", "language.py", "lm.py",
	  "myhttpbase.py", "myserver.py", "sc.py",
	  "komtext.py", "toolbar.py", "log.py", "estring.py"]

for p in python:
    t.add_dep(item(p))

m.add_target(t, None, ["WWW_KOM"])

m.add_target(generated_python_file("komconfig.py"), "all", ["WWW_KOM"])

m.emit()

print """
# Where to install Python files
pydir = $(datadir)/wwwkom/$(VERSION)/py
htmldir = $(datadir)/wwwkom/$(VERSION)/html

sc: $(srcdir)/sc.sh Makefile
	$(RM) sc.tmp
	sed \\
		-e "s/SERVER/$(DEFAULT_SERVER)/" \\
		-e "s/PORT/$(DEFAULT_PORT)/" \\
		-e "s+PYDIR+$(pydir)+" \\
		-e "s+HTMLDIR+$(htmldir)+" \\
		-e "s+BINDIR+$(bindir)+" \\
		< $(srcdir)/sc.sh > sc.tmp
	chmod +x sc.tmp
	mv -f sc.tmp sc

lm: $(srcdir)/lm.sh Makefile
	$(RM) lm.tmp
	sed \\
		-e "s/SERVER/$(DEFAULT_SERVER)/" \\
		-e "s/PORT/$(DEFAULT_PORT)/" \\
		-e "s+PYDIR+$(pydir)+" \\
		-e "s+HTMLDIR+$(htmldir)+" \\
		-e "s+BINDIR+$(bindir)+" \\
		< $(srcdir)/lm.sh > lm.tmp
	chmod +x lm.tmp
	mv -f lm.tmp lm

komconfig.py: Makefile
	(echo 'wwwhost="'`hostname`.`domainname`'"'; echo 'wwwport="'8494'"') > komconfig.py
"""
